@@ -12,6 +12,7 @@
 
 #include <QDialogButtonBox>
 #include <QMessageBox>
+#include <QStringList>
 
 #include <kguiitem.h>
 #include <kstandardguiitem.h>
@@ -23,7 +24,6 @@ class KMessageBoxNotifyInterface;
 class QDialog;
 class QDialogButtonBox;
 class QWidget;
-class QStringList;
 class KConfig;
 
 /**
@@ -44,7 +44,7 @@ namespace KMessageBox
 {
 /**
  * Button types.
- **/
+ */
 enum ButtonCode {
     Ok = 1,
     Cancel = 2,
@@ -82,13 +82,9 @@ enum Option {
  */
 Q_DECLARE_FLAGS(Options, Option)
 
-} // namespace
+// This declaration must be defined before first Option is used in method signatures
+Q_DECLARE_OPERATORS_FOR_FLAGS(Options)
 
-// This declaration must be defined before first Option is used in method signatures AND outside the namespace
-Q_DECLARE_OPERATORS_FOR_FLAGS(KMessageBox::Options)
-
-namespace KMessageBox
-{
 /**
  * Display a simple "question" dialog.
  *
@@ -116,7 +112,6 @@ namespace KMessageBox
  *
  * The default button is "Yes". Pressing "Esc" selects "No".
  */
-
 KWIDGETSADDONS_EXPORT ButtonCode questionYesNo(QWidget *parent,
         const QString &text,
         const QString &caption = QString(),
@@ -153,7 +148,6 @@ KWIDGETSADDONS_EXPORT ButtonCode questionYesNo(QWidget *parent,
  *
  * The default button is "Yes". Pressing "Esc" selects "Cancel".
  */
-
 KWIDGETSADDONS_EXPORT ButtonCode questionYesNoCancel(QWidget *parent,
         const QString &text,
         const QString &caption = QString(),
@@ -194,7 +188,6 @@ KWIDGETSADDONS_EXPORT ButtonCode questionYesNoCancel(QWidget *parent,
  *
  * The default button is "Yes". Pressing "Esc" selects "No".
  */
-
 KWIDGETSADDONS_EXPORT ButtonCode questionYesNoList(QWidget *parent,
         const QString &text,
         const QStringList &strlist,
@@ -271,7 +264,6 @@ KWIDGETSADDONS_EXPORT ButtonCode warningYesNo(QWidget *parent,
  *
  * The default button is "No". Pressing "Esc" selects "No".
  */
-
 KWIDGETSADDONS_EXPORT ButtonCode warningYesNoList(QWidget *parent,
         const QString &text,
         const QStringList &strlist,
@@ -405,7 +397,6 @@ KWIDGETSADDONS_EXPORT ButtonCode warningContinueCancelList(QWidget *parent,
  *
  * The default button is "Yes". Pressing "Esc" selects "Cancel"
  */
-
 KWIDGETSADDONS_EXPORT ButtonCode warningYesNoCancel(QWidget *parent,
         const QString &text,
         const QString &caption = QString(),
@@ -480,9 +471,8 @@ KWIDGETSADDONS_EXPORT ButtonCode warningYesNoCancelList(QWidget *parent,
  *
  * The default button is "&OK". Pressing "Esc" selects the OK-button.
  *
- * NOTE: The OK button will always have the i18n'ed text '&OK'.
+ * @note The OK button will always have the i18n'ed text '&OK'.
  */
-
 KWIDGETSADDONS_EXPORT void error(QWidget *parent,
                                  const QString &text,
                                  const QString &caption = QString(),
@@ -509,9 +499,8 @@ KWIDGETSADDONS_EXPORT void error(QWidget *parent,
  *
  * The default button is "&OK". Pressing "Esc" selects the OK-button.
  *
- * NOTE: The OK button will always have the i18n'ed text '&OK'.
+ * @note The OK button will always have the i18n'ed text '&OK'.
  */
-
 KWIDGETSADDONS_EXPORT void errorList(QWidget *parent,
                                      const QString &text,
                                      const QStringList &strlist,
@@ -540,7 +529,7 @@ KWIDGETSADDONS_EXPORT void errorList(QWidget *parent,
  *
  * The default button is "&OK". Pressing "Esc" selects the OK-button.
  *
- * NOTE: The OK button will always have the i18n'ed text '&OK'.
+ * @note The OK button will always have the i18n'ed text '&OK'.
  */
 KWIDGETSADDONS_EXPORT void detailedError(QWidget *parent,
         const QString &text,
@@ -565,7 +554,7 @@ KWIDGETSADDONS_EXPORT void detailedError(QWidget *parent,
  *
  * The default button is "&OK". Pressing "Esc" selects the OK-button.
  *
- * NOTE: The ok button will always have the i18n'ed text '&OK'.
+ * @note The OK button will always have the i18n'ed text '&OK'.
  * See the overload with a KGuiItem argument to change that.
  */
 KWIDGETSADDONS_EXPORT void sorry(QWidget *parent,
@@ -624,10 +613,9 @@ KWIDGETSADDONS_EXPORT void sorry(QWidget *parent,
  *
  * The default button is "&OK". Pressing "Esc" selects the OK-button.
  *
- * NOTE: The ok button will always have the i18n'ed text '&OK'.
+ * @note The OK button will always have the i18n'ed text '&OK'.
  * See the overload with a KGuiItem argument to change that.
  */
-
 KWIDGETSADDONS_EXPORT void detailedSorry(QWidget *parent,
         const QString &text,
         const QString &details,
@@ -660,7 +648,6 @@ KWIDGETSADDONS_EXPORT void detailedSorry(QWidget *parent,
  * There is only one button, therefore it's the default button, and pressing "Esc" selects it as well.
  * @since 5.63
  */
-
 KWIDGETSADDONS_EXPORT void detailedSorry(QWidget *parent,
         const QString &text,
         const QString &details,
@@ -689,9 +676,8 @@ KWIDGETSADDONS_EXPORT void detailedSorry(QWidget *parent,
  *
  * The default button is "&OK". Pressing "Esc" selects the OK-button.
  *
- *  NOTE: The OK button will always have the i18n'ed text '&OK'.
+ *  @note The OK button will always have the i18n'ed text '&OK'.
  */
-
 KWIDGETSADDONS_EXPORT void information(QWidget *parent,
                                        const QString &text,
                                        const QString &caption = QString(),
@@ -722,9 +708,8 @@ KWIDGETSADDONS_EXPORT void information(QWidget *parent,
  *
  * The default button is "&OK". Pressing "Esc" selects the OK-button.
  *
- *  NOTE: The OK button will always have the i18n'ed text '&OK'.
+ *  @note The OK button will always have the i18n'ed text '&OK'.
  */
-
 KWIDGETSADDONS_EXPORT void informationList(QWidget *parent,
         const QString &text,
         const QStringList &strlist,
@@ -761,7 +746,7 @@ KWIDGETSADDONS_EXPORT void enableMessage(const QString &dontShowAgainName);
  *
  * The default button is "&OK".
  *
- *  NOTE: The ok button will always have the i18n'ed text '&OK'.
+ *  @note The OK button will always have the i18n'ed text '&OK'.
  */
 KWIDGETSADDONS_EXPORT void about(QWidget *parent,
                                  const QString &text,
@@ -792,7 +777,6 @@ KWIDGETSADDONS_EXPORT void about(QWidget *parent,
  *       and for Information, none is used.
  * @return a button code, as defined in KMessageBox.
  */
-
 KWIDGETSADDONS_EXPORT ButtonCode messageBox(QWidget *parent, DialogType type, const QString &text,
         const QString &caption = QString(),
         const KGuiItem &buttonYes = KStandardGuiItem::yes(),
