@@ -10,9 +10,9 @@
 
 #include <QWidget>
 #include <QLineEdit>
+#include <memory>
 #include <kwidgetsaddons_export.h>
 class QAction;
-class KPasswordLineEditPrivate;
 
 /**
  * @class KPasswordLineEdit kpasswordlineedit.h KPasswordLineEdit
@@ -31,7 +31,6 @@ class KPasswordLineEditPrivate;
  * @author Laurent Montel <montel@kde.org>
  * @since 5.37
  */
-
 class KWIDGETSADDONS_EXPORT KPasswordLineEdit : public QWidget
 {
     Q_OBJECT
@@ -119,7 +118,7 @@ Q_SIGNALS:
     void passwordChanged(const QString &password);
 
 private:
-    KPasswordLineEditPrivate *const d;
+    std::unique_ptr<class KPasswordLineEditPrivate> const d;
 };
 
 #endif
